============================================
CuPy -- NumPy-like API accelerated with CUDA
============================================

This is the `CuPy <https://github.com/cupy/cupy>`_ documentation.

.. module:: cupy

.. toctree::
   :maxdepth: 2

   overview
   tutorial/index
   reference/index

.. toctree::
   :maxdepth: 2
   :caption: Development

   compatibility
   contribution

.. toctree::
   :maxdepth: 2
   :caption: Misc Notes

   install
   install_rocm
   upgrade
   license
